actionAsync method

  1. @override
Future<void> actionAsync(
  1. PVLogEvent event
)
override

Asynchronously processes a log event.

This method is called for async logging operations when isAsync is true, or for all Action adapters during async logging calls.

Implementation

@override
Future<void> actionAsync(PVLogEvent event) {
  throw UnimplementedError();
}