actionAsync method
Asynchronously processes a log event.
This method is called for async logging operations when isAsync is true, or for all Action adapters during async logging calls.
Implementation
@override
Future<void> actionAsync(PVLogEvent event) {
throw UnimplementedError();
}