iconList top-level constant
Icons representing different log levels from low to high severity.
These icons are used by PVLogNicerPrinter to provide visual indicators for different severity levels in log output. The array is indexed by log level (0-9), with higher indices representing higher severity.
Levels:
- 0: đ trace/debug - magnifying glass for detailed inspection
- 1: âšī¸ info - information symbol
- 2: đ notice - memo/note for notable events
- 3: đĄ suggestion - lightbulb for hints/tips
- 4: â ī¸ warning - warning triangle
- 5: â error - exclamation mark for errors
- 6: đ¨ critical - alarm/siren for critical issues
- 7: đĨ fatal - explosion for system failures
- 8: đĨ emergency - fire for urgent situations
- 9: â ī¸ catastrophic - skull for catastrophic failures
Implementation
const iconList = [
'đ', // 0 - trace/debug - magnifying glass for detailed inspection
'âšī¸', // 1 - info - information symbol
'đ', // 2 - notice - memo/note for notable events
'đĄ', // 3 - suggestion - lightbulb for hints/tips
'â ī¸', // 4 - warning - warning triangle
'â', // 5 - error - exclamation mark for errors
'đ¨', // 6 - critical - alarm/siren for critical issues
'đĨ', // 7 - fatal - explosion for system failures
'đĨ', // 8 - emergency - fire for urgent situations
'â ī¸', // 9 - catastrophic - skull for catastrophic failures
];