PVStdFormatter class
Standard formatter that prepares log data for printing adapters.
This EventBuilder adapter processes log events and creates formatted representations using JSON serialization. It handles both regular messages and error events with special formatting.
The formatter only processes events when print adapters are present in the pipeline, optimizing performance when printing is not needed.
Created extra data:
- 'pvlogger_formatted': Contains the JSON-formatted raw message
- 'pvlogger_catch_error_formatted': Contains formatted error and stack trace (only for catch error events)
- Inheritance
-
- Object
- PVLogAdapter
- PVStdFormatter
- Mixed-in types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
intents
→ List<
AdapterIntent> -
The types of operations this adapter can perform.
no setterinherited
- levelFilter → int?
-
The minimum level required for events to be processed by this adapter.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildEvent(
PreEventContext context, List< PVLogAdapter> upcomingAdapters) → void -
Formats log data for printing adapters.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited